/***************************************************************************//**
* \file CapSense_RegisterMap.h
* \version 5.0
*
* \brief
*   This file provides the definitions for the Component data structure register.
*
* \see CapSense v5.0 Datasheet
*
*//*****************************************************************************
* Copyright (2016-2017), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and
* foreign), United States copyright laws and international treaty provisions.
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the
* Cypress Source Code and derivative works for the sole purpose of creating
* custom software in support of licensee product to be used only in conjunction
* with a Cypress integrated circuit as specified in the applicable agreement.
* Any reproduction, modification, translation, compilation, or representation of
* this software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising out
* of the application or use of any product or circuit described herein. Cypress
* does not authorize its products for use as critical components in life-support
* systems where a malfunction or failure may reasonably be expected to result in
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of
* such use and in doing so indemnifies Cypress against all charges. Use may be
* limited by and subject to the applicable Cypress software license agreement.
*******************************************************************************/

#if !defined(CY_SENSE_CapSense_REGISTER_MAP_H)
#define CY_SENSE_CapSense_REGISTER_MAP_H

#include <cytypes.h>
#include "CapSense_Configuration.h"
#include "CapSense_Structure.h"

/*****************************************************************************/
/* RAM Data structure register definitions                                   */
/*****************************************************************************/
#define CapSense_CONFIG_ID_VALUE                            (CapSense_dsRam.configId)
#define CapSense_CONFIG_ID_OFFSET                           (0u)
#define CapSense_CONFIG_ID_SIZE                             (2u)
#define CapSense_CONFIG_ID_PARAM_ID                         (0x87000000u)

#define CapSense_DEVICE_ID_VALUE                            (CapSense_dsRam.deviceId)
#define CapSense_DEVICE_ID_OFFSET                           (2u)
#define CapSense_DEVICE_ID_SIZE                             (2u)
#define CapSense_DEVICE_ID_PARAM_ID                         (0x8B000002u)

#define CapSense_HW_CLOCK_VALUE                             (CapSense_dsRam.hwClock)
#define CapSense_HW_CLOCK_OFFSET                            (4u)
#define CapSense_HW_CLOCK_SIZE                              (2u)
#define CapSense_HW_CLOCK_PARAM_ID                          (0x86000004u)

#define CapSense_TUNER_CMD_VALUE                            (CapSense_dsRam.tunerCmd)
#define CapSense_TUNER_CMD_OFFSET                           (6u)
#define CapSense_TUNER_CMD_SIZE                             (2u)
#define CapSense_TUNER_CMD_PARAM_ID                         (0xA1000006u)

#define CapSense_SCAN_COUNTER_VALUE                         (CapSense_dsRam.scanCounter)
#define CapSense_SCAN_COUNTER_OFFSET                        (8u)
#define CapSense_SCAN_COUNTER_SIZE                          (2u)
#define CapSense_SCAN_COUNTER_PARAM_ID                      (0x85000008u)

#define CapSense_STATUS_VALUE                               (CapSense_dsRam.status)
#define CapSense_STATUS_OFFSET                              (12u)
#define CapSense_STATUS_SIZE                                (4u)
#define CapSense_STATUS_PARAM_ID                            (0xCB00000Cu)

#define CapSense_WDGT_ENABLE0_VALUE                         (CapSense_dsRam.wdgtEnable[0u])
#define CapSense_WDGT_ENABLE0_OFFSET                        (16u)
#define CapSense_WDGT_ENABLE0_SIZE                          (4u)
#define CapSense_WDGT_ENABLE0_PARAM_ID                      (0xE6000010u)

#define CapSense_WDGT_WORKING0_VALUE                        (CapSense_dsRam.wdgtWorking[0u])
#define CapSense_WDGT_WORKING0_OFFSET                       (20u)
#define CapSense_WDGT_WORKING0_SIZE                         (4u)
#define CapSense_WDGT_WORKING0_PARAM_ID                     (0xCC000014u)

#define CapSense_WDGT_STATUS0_VALUE                         (CapSense_dsRam.wdgtStatus[0u])
#define CapSense_WDGT_STATUS0_OFFSET                        (24u)
#define CapSense_WDGT_STATUS0_SIZE                          (4u)
#define CapSense_WDGT_STATUS0_PARAM_ID                      (0xCF000018u)

#define CapSense_SNS_STATUS0_VALUE                          (CapSense_dsRam.snsStatus[0u])
#define CapSense_SNS_STATUS0_OFFSET                         (28u)
#define CapSense_SNS_STATUS0_SIZE                           (1u)
#define CapSense_SNS_STATUS0_PARAM_ID                       (0x4900001Cu)

#define CapSense_SNS_STATUS1_VALUE                          (CapSense_dsRam.snsStatus[1u])
#define CapSense_SNS_STATUS1_OFFSET                         (29u)
#define CapSense_SNS_STATUS1_SIZE                           (1u)
#define CapSense_SNS_STATUS1_PARAM_ID                       (0x4F00001Du)

#define CapSense_SNS_STATUS2_VALUE                          (CapSense_dsRam.snsStatus[2u])
#define CapSense_SNS_STATUS2_OFFSET                         (30u)
#define CapSense_SNS_STATUS2_SIZE                           (1u)
#define CapSense_SNS_STATUS2_PARAM_ID                       (0x4500001Eu)

#define CapSense_CSD0_CONFIG_VALUE                          (CapSense_dsRam.csd0Config)
#define CapSense_CSD0_CONFIG_OFFSET                         (32u)
#define CapSense_CSD0_CONFIG_SIZE                           (2u)
#define CapSense_CSD0_CONFIG_PARAM_ID                       (0xAB800020u)

#define CapSense_MOD_CSD_CLK_VALUE                          (CapSense_dsRam.modCsdClk)
#define CapSense_MOD_CSD_CLK_OFFSET                         (34u)
#define CapSense_MOD_CSD_CLK_SIZE                           (1u)
#define CapSense_MOD_CSD_CLK_PARAM_ID                       (0x6F800022u)

#define CapSense_GLB_CRC_VALUE                              (CapSense_dsRam.glbCrc)
#define CapSense_GLB_CRC_OFFSET                             (36u)
#define CapSense_GLB_CRC_SIZE                               (2u)
#define CapSense_GLB_CRC_PARAM_ID                           (0x8C000024u)

#define CapSense_BTN0_CRC_VALUE                             (CapSense_dsRam.wdgtList.btn0.crc)
#define CapSense_BTN0_CRC_OFFSET                            (38u)
#define CapSense_BTN0_CRC_SIZE                              (2u)
#define CapSense_BTN0_CRC_PARAM_ID                          (0x80000026u)

#define CapSense_BTN0_RESOLUTION_VALUE                      (CapSense_dsRam.wdgtList.btn0.resolution)
#define CapSense_BTN0_RESOLUTION_OFFSET                     (40u)
#define CapSense_BTN0_RESOLUTION_SIZE                       (2u)
#define CapSense_BTN0_RESOLUTION_PARAM_ID                   (0xA9800028u)

#define CapSense_BTN0_FINGER_TH_VALUE                       (CapSense_dsRam.wdgtList.btn0.fingerTh)
#define CapSense_BTN0_FINGER_TH_OFFSET                      (42u)
#define CapSense_BTN0_FINGER_TH_SIZE                        (2u)
#define CapSense_BTN0_FINGER_TH_PARAM_ID                    (0xA580002Au)

#define CapSense_BTN0_NOISE_TH_VALUE                        (CapSense_dsRam.wdgtList.btn0.noiseTh)
#define CapSense_BTN0_NOISE_TH_OFFSET                       (44u)
#define CapSense_BTN0_NOISE_TH_SIZE                         (1u)
#define CapSense_BTN0_NOISE_TH_PARAM_ID                     (0x6080002Cu)

#define CapSense_BTN0_NNOISE_TH_VALUE                       (CapSense_dsRam.wdgtList.btn0.nNoiseTh)
#define CapSense_BTN0_NNOISE_TH_OFFSET                      (45u)
#define CapSense_BTN0_NNOISE_TH_SIZE                        (1u)
#define CapSense_BTN0_NNOISE_TH_PARAM_ID                    (0x6680002Du)

#define CapSense_BTN0_HYSTERESIS_VALUE                      (CapSense_dsRam.wdgtList.btn0.hysteresis)
#define CapSense_BTN0_HYSTERESIS_OFFSET                     (46u)
#define CapSense_BTN0_HYSTERESIS_SIZE                       (1u)
#define CapSense_BTN0_HYSTERESIS_PARAM_ID                   (0x6C80002Eu)

#define CapSense_BTN0_ON_DEBOUNCE_VALUE                     (CapSense_dsRam.wdgtList.btn0.onDebounce)
#define CapSense_BTN0_ON_DEBOUNCE_OFFSET                    (47u)
#define CapSense_BTN0_ON_DEBOUNCE_SIZE                      (1u)
#define CapSense_BTN0_ON_DEBOUNCE_PARAM_ID                  (0x6A80002Fu)

#define CapSense_BTN0_LOW_BSLN_RST_VALUE                    (CapSense_dsRam.wdgtList.btn0.lowBslnRst)
#define CapSense_BTN0_LOW_BSLN_RST_OFFSET                   (48u)
#define CapSense_BTN0_LOW_BSLN_RST_SIZE                     (1u)
#define CapSense_BTN0_LOW_BSLN_RST_PARAM_ID                 (0x66800030u)

#define CapSense_BTN0_IDAC_MOD0_VALUE                       (CapSense_dsRam.wdgtList.btn0.idacMod[0u])
#define CapSense_BTN0_IDAC_MOD0_OFFSET                      (49u)
#define CapSense_BTN0_IDAC_MOD0_SIZE                        (1u)
#define CapSense_BTN0_IDAC_MOD0_PARAM_ID                    (0x46000031u)

#define CapSense_BTN0_SNS_CLK_VALUE                         (CapSense_dsRam.wdgtList.btn0.snsClk)
#define CapSense_BTN0_SNS_CLK_OFFSET                        (50u)
#define CapSense_BTN0_SNS_CLK_SIZE                          (2u)
#define CapSense_BTN0_SNS_CLK_PARAM_ID                      (0xA2800032u)

#define CapSense_BTN0_SNS_CLK_SOURCE_VALUE                  (CapSense_dsRam.wdgtList.btn0.snsClkSource)
#define CapSense_BTN0_SNS_CLK_SOURCE_OFFSET                 (52u)
#define CapSense_BTN0_SNS_CLK_SOURCE_SIZE                   (1u)
#define CapSense_BTN0_SNS_CLK_SOURCE_PARAM_ID               (0x4C800034u)

#define CapSense_BTN1_CRC_VALUE                             (CapSense_dsRam.wdgtList.btn1.crc)
#define CapSense_BTN1_CRC_OFFSET                            (54u)
#define CapSense_BTN1_CRC_SIZE                              (2u)
#define CapSense_BTN1_CRC_PARAM_ID                          (0x86010036u)

#define CapSense_BTN1_RESOLUTION_VALUE                      (CapSense_dsRam.wdgtList.btn1.resolution)
#define CapSense_BTN1_RESOLUTION_OFFSET                     (56u)
#define CapSense_BTN1_RESOLUTION_SIZE                       (2u)
#define CapSense_BTN1_RESOLUTION_PARAM_ID                   (0xAF810038u)

#define CapSense_BTN1_FINGER_TH_VALUE                       (CapSense_dsRam.wdgtList.btn1.fingerTh)
#define CapSense_BTN1_FINGER_TH_OFFSET                      (58u)
#define CapSense_BTN1_FINGER_TH_SIZE                        (2u)
#define CapSense_BTN1_FINGER_TH_PARAM_ID                    (0xA381003Au)

#define CapSense_BTN1_NOISE_TH_VALUE                        (CapSense_dsRam.wdgtList.btn1.noiseTh)
#define CapSense_BTN1_NOISE_TH_OFFSET                       (60u)
#define CapSense_BTN1_NOISE_TH_SIZE                         (1u)
#define CapSense_BTN1_NOISE_TH_PARAM_ID                     (0x6681003Cu)

#define CapSense_BTN1_NNOISE_TH_VALUE                       (CapSense_dsRam.wdgtList.btn1.nNoiseTh)
#define CapSense_BTN1_NNOISE_TH_OFFSET                      (61u)
#define CapSense_BTN1_NNOISE_TH_SIZE                        (1u)
#define CapSense_BTN1_NNOISE_TH_PARAM_ID                    (0x6081003Du)

#define CapSense_BTN1_HYSTERESIS_VALUE                      (CapSense_dsRam.wdgtList.btn1.hysteresis)
#define CapSense_BTN1_HYSTERESIS_OFFSET                     (62u)
#define CapSense_BTN1_HYSTERESIS_SIZE                       (1u)
#define CapSense_BTN1_HYSTERESIS_PARAM_ID                   (0x6A81003Eu)

#define CapSense_BTN1_ON_DEBOUNCE_VALUE                     (CapSense_dsRam.wdgtList.btn1.onDebounce)
#define CapSense_BTN1_ON_DEBOUNCE_OFFSET                    (63u)
#define CapSense_BTN1_ON_DEBOUNCE_SIZE                      (1u)
#define CapSense_BTN1_ON_DEBOUNCE_PARAM_ID                  (0x6C81003Fu)

#define CapSense_BTN1_LOW_BSLN_RST_VALUE                    (CapSense_dsRam.wdgtList.btn1.lowBslnRst)
#define CapSense_BTN1_LOW_BSLN_RST_OFFSET                   (64u)
#define CapSense_BTN1_LOW_BSLN_RST_SIZE                     (1u)
#define CapSense_BTN1_LOW_BSLN_RST_PARAM_ID                 (0x67810040u)

#define CapSense_BTN1_IDAC_MOD0_VALUE                       (CapSense_dsRam.wdgtList.btn1.idacMod[0u])
#define CapSense_BTN1_IDAC_MOD0_OFFSET                      (65u)
#define CapSense_BTN1_IDAC_MOD0_SIZE                        (1u)
#define CapSense_BTN1_IDAC_MOD0_PARAM_ID                    (0x47010041u)

#define CapSense_BTN1_SNS_CLK_VALUE                         (CapSense_dsRam.wdgtList.btn1.snsClk)
#define CapSense_BTN1_SNS_CLK_OFFSET                        (66u)
#define CapSense_BTN1_SNS_CLK_SIZE                          (2u)
#define CapSense_BTN1_SNS_CLK_PARAM_ID                      (0xA3810042u)

#define CapSense_BTN1_SNS_CLK_SOURCE_VALUE                  (CapSense_dsRam.wdgtList.btn1.snsClkSource)
#define CapSense_BTN1_SNS_CLK_SOURCE_OFFSET                 (68u)
#define CapSense_BTN1_SNS_CLK_SOURCE_SIZE                   (1u)
#define CapSense_BTN1_SNS_CLK_SOURCE_PARAM_ID               (0x4D810044u)

#define CapSense_BTN2_CRC_VALUE                             (CapSense_dsRam.wdgtList.btn2.crc)
#define CapSense_BTN2_CRC_OFFSET                            (70u)
#define CapSense_BTN2_CRC_SIZE                              (2u)
#define CapSense_BTN2_CRC_PARAM_ID                          (0x81020046u)

#define CapSense_BTN2_RESOLUTION_VALUE                      (CapSense_dsRam.wdgtList.btn2.resolution)
#define CapSense_BTN2_RESOLUTION_OFFSET                     (72u)
#define CapSense_BTN2_RESOLUTION_SIZE                       (2u)
#define CapSense_BTN2_RESOLUTION_PARAM_ID                   (0xA8820048u)

#define CapSense_BTN2_FINGER_TH_VALUE                       (CapSense_dsRam.wdgtList.btn2.fingerTh)
#define CapSense_BTN2_FINGER_TH_OFFSET                      (74u)
#define CapSense_BTN2_FINGER_TH_SIZE                        (2u)
#define CapSense_BTN2_FINGER_TH_PARAM_ID                    (0xA482004Au)

#define CapSense_BTN2_NOISE_TH_VALUE                        (CapSense_dsRam.wdgtList.btn2.noiseTh)
#define CapSense_BTN2_NOISE_TH_OFFSET                       (76u)
#define CapSense_BTN2_NOISE_TH_SIZE                         (1u)
#define CapSense_BTN2_NOISE_TH_PARAM_ID                     (0x6182004Cu)

#define CapSense_BTN2_NNOISE_TH_VALUE                       (CapSense_dsRam.wdgtList.btn2.nNoiseTh)
#define CapSense_BTN2_NNOISE_TH_OFFSET                      (77u)
#define CapSense_BTN2_NNOISE_TH_SIZE                        (1u)
#define CapSense_BTN2_NNOISE_TH_PARAM_ID                    (0x6782004Du)

#define CapSense_BTN2_HYSTERESIS_VALUE                      (CapSense_dsRam.wdgtList.btn2.hysteresis)
#define CapSense_BTN2_HYSTERESIS_OFFSET                     (78u)
#define CapSense_BTN2_HYSTERESIS_SIZE                       (1u)
#define CapSense_BTN2_HYSTERESIS_PARAM_ID                   (0x6D82004Eu)

#define CapSense_BTN2_ON_DEBOUNCE_VALUE                     (CapSense_dsRam.wdgtList.btn2.onDebounce)
#define CapSense_BTN2_ON_DEBOUNCE_OFFSET                    (79u)
#define CapSense_BTN2_ON_DEBOUNCE_SIZE                      (1u)
#define CapSense_BTN2_ON_DEBOUNCE_PARAM_ID                  (0x6B82004Fu)

#define CapSense_BTN2_LOW_BSLN_RST_VALUE                    (CapSense_dsRam.wdgtList.btn2.lowBslnRst)
#define CapSense_BTN2_LOW_BSLN_RST_OFFSET                   (80u)
#define CapSense_BTN2_LOW_BSLN_RST_SIZE                     (1u)
#define CapSense_BTN2_LOW_BSLN_RST_PARAM_ID                 (0x67820050u)

#define CapSense_BTN2_IDAC_MOD0_VALUE                       (CapSense_dsRam.wdgtList.btn2.idacMod[0u])
#define CapSense_BTN2_IDAC_MOD0_OFFSET                      (81u)
#define CapSense_BTN2_IDAC_MOD0_SIZE                        (1u)
#define CapSense_BTN2_IDAC_MOD0_PARAM_ID                    (0x47020051u)

#define CapSense_BTN2_SNS_CLK_VALUE                         (CapSense_dsRam.wdgtList.btn2.snsClk)
#define CapSense_BTN2_SNS_CLK_OFFSET                        (82u)
#define CapSense_BTN2_SNS_CLK_SIZE                          (2u)
#define CapSense_BTN2_SNS_CLK_PARAM_ID                      (0xA3820052u)

#define CapSense_BTN2_SNS_CLK_SOURCE_VALUE                  (CapSense_dsRam.wdgtList.btn2.snsClkSource)
#define CapSense_BTN2_SNS_CLK_SOURCE_OFFSET                 (84u)
#define CapSense_BTN2_SNS_CLK_SOURCE_SIZE                   (1u)
#define CapSense_BTN2_SNS_CLK_SOURCE_PARAM_ID               (0x4D820054u)

#define CapSense_BTN0_SNS0_RAW0_VALUE                       (CapSense_dsRam.snsList.btn0[0u].raw[0u])
#define CapSense_BTN0_SNS0_RAW0_OFFSET                      (86u)
#define CapSense_BTN0_SNS0_RAW0_SIZE                        (2u)
#define CapSense_BTN0_SNS0_RAW0_PARAM_ID                    (0x82000056u)

#define CapSense_BTN0_SNS0_BSLN0_VALUE                      (CapSense_dsRam.snsList.btn0[0u].bsln[0u])
#define CapSense_BTN0_SNS0_BSLN0_OFFSET                     (88u)
#define CapSense_BTN0_SNS0_BSLN0_SIZE                       (2u)
#define CapSense_BTN0_SNS0_BSLN0_PARAM_ID                   (0x8D000058u)

#define CapSense_BTN0_SNS0_BSLN_INV0_VALUE                  (CapSense_dsRam.snsList.btn0[0u].bslnInv[0u])
#define CapSense_BTN0_SNS0_BSLN_INV0_OFFSET                 (90u)
#define CapSense_BTN0_SNS0_BSLN_INV0_SIZE                   (2u)
#define CapSense_BTN0_SNS0_BSLN_INV0_PARAM_ID               (0x8100005Au)

#define CapSense_BTN0_SNS0_BSLN_EXT0_VALUE                  (CapSense_dsRam.snsList.btn0[0u].bslnExt[0u])
#define CapSense_BTN0_SNS0_BSLN_EXT0_OFFSET                 (92u)
#define CapSense_BTN0_SNS0_BSLN_EXT0_SIZE                   (1u)
#define CapSense_BTN0_SNS0_BSLN_EXT0_PARAM_ID               (0x4400005Cu)

#define CapSense_BTN0_SNS0_DIFF_VALUE                       (CapSense_dsRam.snsList.btn0[0u].diff)
#define CapSense_BTN0_SNS0_DIFF_OFFSET                      (94u)
#define CapSense_BTN0_SNS0_DIFF_SIZE                        (2u)
#define CapSense_BTN0_SNS0_DIFF_PARAM_ID                    (0x8000005Eu)

#define CapSense_BTN0_SNS0_NEG_BSLN_RST_CNT0_VALUE          (CapSense_dsRam.snsList.btn0[0u].negBslnRstCnt[0u])
#define CapSense_BTN0_SNS0_NEG_BSLN_RST_CNT0_OFFSET         (96u)
#define CapSense_BTN0_SNS0_NEG_BSLN_RST_CNT0_SIZE           (1u)
#define CapSense_BTN0_SNS0_NEG_BSLN_RST_CNT0_PARAM_ID       (0x48000060u)

#define CapSense_BTN0_SNS0_IDAC_COMP0_VALUE                 (CapSense_dsRam.snsList.btn0[0u].idacComp[0u])
#define CapSense_BTN0_SNS0_IDAC_COMP0_OFFSET                (97u)
#define CapSense_BTN0_SNS0_IDAC_COMP0_SIZE                  (1u)
#define CapSense_BTN0_SNS0_IDAC_COMP0_PARAM_ID              (0x4E000061u)

#define CapSense_BTN1_SNS0_RAW0_VALUE                       (CapSense_dsRam.snsList.btn1[0u].raw[0u])
#define CapSense_BTN1_SNS0_RAW0_OFFSET                      (98u)
#define CapSense_BTN1_SNS0_RAW0_SIZE                        (2u)
#define CapSense_BTN1_SNS0_RAW0_PARAM_ID                    (0x8C000062u)

#define CapSense_BTN1_SNS0_BSLN0_VALUE                      (CapSense_dsRam.snsList.btn1[0u].bsln[0u])
#define CapSense_BTN1_SNS0_BSLN0_OFFSET                     (100u)
#define CapSense_BTN1_SNS0_BSLN0_SIZE                       (2u)
#define CapSense_BTN1_SNS0_BSLN0_PARAM_ID                   (0x81000064u)

#define CapSense_BTN1_SNS0_BSLN_INV0_VALUE                  (CapSense_dsRam.snsList.btn1[0u].bslnInv[0u])
#define CapSense_BTN1_SNS0_BSLN_INV0_OFFSET                 (102u)
#define CapSense_BTN1_SNS0_BSLN_INV0_SIZE                   (2u)
#define CapSense_BTN1_SNS0_BSLN_INV0_PARAM_ID               (0x8D000066u)

#define CapSense_BTN1_SNS0_BSLN_EXT0_VALUE                  (CapSense_dsRam.snsList.btn1[0u].bslnExt[0u])
#define CapSense_BTN1_SNS0_BSLN_EXT0_OFFSET                 (104u)
#define CapSense_BTN1_SNS0_BSLN_EXT0_SIZE                   (1u)
#define CapSense_BTN1_SNS0_BSLN_EXT0_PARAM_ID               (0x4A000068u)

#define CapSense_BTN1_SNS0_DIFF_VALUE                       (CapSense_dsRam.snsList.btn1[0u].diff)
#define CapSense_BTN1_SNS0_DIFF_OFFSET                      (106u)
#define CapSense_BTN1_SNS0_DIFF_SIZE                        (2u)
#define CapSense_BTN1_SNS0_DIFF_PARAM_ID                    (0x8E00006Au)

#define CapSense_BTN1_SNS0_NEG_BSLN_RST_CNT0_VALUE          (CapSense_dsRam.snsList.btn1[0u].negBslnRstCnt[0u])
#define CapSense_BTN1_SNS0_NEG_BSLN_RST_CNT0_OFFSET         (108u)
#define CapSense_BTN1_SNS0_NEG_BSLN_RST_CNT0_SIZE           (1u)
#define CapSense_BTN1_SNS0_NEG_BSLN_RST_CNT0_PARAM_ID       (0x4B00006Cu)

#define CapSense_BTN1_SNS0_IDAC_COMP0_VALUE                 (CapSense_dsRam.snsList.btn1[0u].idacComp[0u])
#define CapSense_BTN1_SNS0_IDAC_COMP0_OFFSET                (109u)
#define CapSense_BTN1_SNS0_IDAC_COMP0_SIZE                  (1u)
#define CapSense_BTN1_SNS0_IDAC_COMP0_PARAM_ID              (0x4D00006Du)

#define CapSense_BTN2_SNS0_RAW0_VALUE                       (CapSense_dsRam.snsList.btn2[0u].raw[0u])
#define CapSense_BTN2_SNS0_RAW0_OFFSET                      (110u)
#define CapSense_BTN2_SNS0_RAW0_SIZE                        (2u)
#define CapSense_BTN2_SNS0_RAW0_PARAM_ID                    (0x8F00006Eu)

#define CapSense_BTN2_SNS0_BSLN0_VALUE                      (CapSense_dsRam.snsList.btn2[0u].bsln[0u])
#define CapSense_BTN2_SNS0_BSLN0_OFFSET                     (112u)
#define CapSense_BTN2_SNS0_BSLN0_SIZE                       (2u)
#define CapSense_BTN2_SNS0_BSLN0_PARAM_ID                   (0x85000070u)

#define CapSense_BTN2_SNS0_BSLN_INV0_VALUE                  (CapSense_dsRam.snsList.btn2[0u].bslnInv[0u])
#define CapSense_BTN2_SNS0_BSLN_INV0_OFFSET                 (114u)
#define CapSense_BTN2_SNS0_BSLN_INV0_SIZE                   (2u)
#define CapSense_BTN2_SNS0_BSLN_INV0_PARAM_ID               (0x89000072u)

#define CapSense_BTN2_SNS0_BSLN_EXT0_VALUE                  (CapSense_dsRam.snsList.btn2[0u].bslnExt[0u])
#define CapSense_BTN2_SNS0_BSLN_EXT0_OFFSET                 (116u)
#define CapSense_BTN2_SNS0_BSLN_EXT0_SIZE                   (1u)
#define CapSense_BTN2_SNS0_BSLN_EXT0_PARAM_ID               (0x4C000074u)

#define CapSense_BTN2_SNS0_DIFF_VALUE                       (CapSense_dsRam.snsList.btn2[0u].diff)
#define CapSense_BTN2_SNS0_DIFF_OFFSET                      (118u)
#define CapSense_BTN2_SNS0_DIFF_SIZE                        (2u)
#define CapSense_BTN2_SNS0_DIFF_PARAM_ID                    (0x88000076u)

#define CapSense_BTN2_SNS0_NEG_BSLN_RST_CNT0_VALUE          (CapSense_dsRam.snsList.btn2[0u].negBslnRstCnt[0u])
#define CapSense_BTN2_SNS0_NEG_BSLN_RST_CNT0_OFFSET         (120u)
#define CapSense_BTN2_SNS0_NEG_BSLN_RST_CNT0_SIZE           (1u)
#define CapSense_BTN2_SNS0_NEG_BSLN_RST_CNT0_PARAM_ID       (0x4F000078u)

#define CapSense_BTN2_SNS0_IDAC_COMP0_VALUE                 (CapSense_dsRam.snsList.btn2[0u].idacComp[0u])
#define CapSense_BTN2_SNS0_IDAC_COMP0_OFFSET                (121u)
#define CapSense_BTN2_SNS0_IDAC_COMP0_SIZE                  (1u)
#define CapSense_BTN2_SNS0_IDAC_COMP0_PARAM_ID              (0x49000079u)

#define CapSense_TEST_RESULT_MASK_VALUE                     (CapSense_dsRam.selfTest.testResultMask)
#define CapSense_TEST_RESULT_MASK_OFFSET                    (124u)
#define CapSense_TEST_RESULT_MASK_SIZE                      (4u)
#define CapSense_TEST_RESULT_MASK_PARAM_ID                  (0xE200007Cu)

#define CapSense_EXT_CAP0_VALUE                             (CapSense_dsRam.selfTest.extCap[0u])
#define CapSense_EXT_CAP0_OFFSET                            (128u)
#define CapSense_EXT_CAP0_SIZE                              (2u)
#define CapSense_EXT_CAP0_PARAM_ID                          (0xAF000080u)

#define CapSense_VDDA_VOLTAGE_VALUE                         (CapSense_dsRam.selfTest.vddaVoltage)
#define CapSense_VDDA_VOLTAGE_OFFSET                        (130u)
#define CapSense_VDDA_VOLTAGE_SIZE                          (2u)
#define CapSense_VDDA_VOLTAGE_PARAM_ID                      (0xA3000082u)

#define CapSense_GLB_CRC_CALC_VALUE                         (CapSense_dsRam.selfTest.glbCrcCalc)
#define CapSense_GLB_CRC_CALC_OFFSET                        (132u)
#define CapSense_GLB_CRC_CALC_SIZE                          (2u)
#define CapSense_GLB_CRC_CALC_PARAM_ID                      (0xAE000084u)

#define CapSense_WDGT_CRC_CALC_VALUE                        (CapSense_dsRam.selfTest.wdgtCrcCalc)
#define CapSense_WDGT_CRC_CALC_OFFSET                       (134u)
#define CapSense_WDGT_CRC_CALC_SIZE                         (2u)
#define CapSense_WDGT_CRC_CALC_PARAM_ID                     (0xA2000086u)

#define CapSense_WDGT_CRC_ID_VALUE                          (CapSense_dsRam.selfTest.wdgtCrcId)
#define CapSense_WDGT_CRC_ID_OFFSET                         (136u)
#define CapSense_WDGT_CRC_ID_SIZE                           (1u)
#define CapSense_WDGT_CRC_ID_PARAM_ID                       (0x65000088u)

#define CapSense_INV_BSLN_WDGT_ID_VALUE                     (CapSense_dsRam.selfTest.invBslnWdgtId)
#define CapSense_INV_BSLN_WDGT_ID_OFFSET                    (137u)
#define CapSense_INV_BSLN_WDGT_ID_SIZE                      (1u)
#define CapSense_INV_BSLN_WDGT_ID_PARAM_ID                  (0x63000089u)

#define CapSense_INV_BSLN_SNS_ID_VALUE                      (CapSense_dsRam.selfTest.invBslnSnsId)
#define CapSense_INV_BSLN_SNS_ID_OFFSET                     (138u)
#define CapSense_INV_BSLN_SNS_ID_SIZE                       (1u)
#define CapSense_INV_BSLN_SNS_ID_PARAM_ID                   (0x6900008Au)

#define CapSense_SHORTED_WDGT_ID_VALUE                      (CapSense_dsRam.selfTest.shortedWdgtId)
#define CapSense_SHORTED_WDGT_ID_OFFSET                     (139u)
#define CapSense_SHORTED_WDGT_ID_SIZE                       (1u)
#define CapSense_SHORTED_WDGT_ID_PARAM_ID                   (0x6F00008Bu)

#define CapSense_SHORTED_SNS_ID_VALUE                       (CapSense_dsRam.selfTest.shortedSnsId)
#define CapSense_SHORTED_SNS_ID_OFFSET                      (140u)
#define CapSense_SHORTED_SNS_ID_SIZE                        (1u)
#define CapSense_SHORTED_SNS_ID_PARAM_ID                    (0x6400008Cu)

#define CapSense_P2P_WDGT_ID_VALUE                          (CapSense_dsRam.selfTest.p2pWdgtId)
#define CapSense_P2P_WDGT_ID_OFFSET                         (141u)
#define CapSense_P2P_WDGT_ID_SIZE                           (1u)
#define CapSense_P2P_WDGT_ID_PARAM_ID                       (0x6200008Du)

#define CapSense_P2P_SNS_ID_VALUE                           (CapSense_dsRam.selfTest.p2pSnsId)
#define CapSense_P2P_SNS_ID_OFFSET                          (142u)
#define CapSense_P2P_SNS_ID_SIZE                            (1u)
#define CapSense_P2P_SNS_ID_PARAM_ID                        (0x6800008Eu)

#define CapSense_BTN0_SNS_CP0_VALUE                         (CapSense_dsRam.snsCp.btn0[0u])
#define CapSense_BTN0_SNS_CP0_OFFSET                        (144u)
#define CapSense_BTN0_SNS_CP0_SIZE                          (1u)
#define CapSense_BTN0_SNS_CP0_PARAM_ID                      (0x62000090u)

#define CapSense_BTN1_SNS_CP0_VALUE                         (CapSense_dsRam.snsCp.btn1[0u])
#define CapSense_BTN1_SNS_CP0_OFFSET                        (145u)
#define CapSense_BTN1_SNS_CP0_SIZE                          (1u)
#define CapSense_BTN1_SNS_CP0_PARAM_ID                      (0x64000091u)

#define CapSense_BTN2_SNS_CP0_VALUE                         (CapSense_dsRam.snsCp.btn2[0u])
#define CapSense_BTN2_SNS_CP0_OFFSET                        (146u)
#define CapSense_BTN2_SNS_CP0_SIZE                          (1u)
#define CapSense_BTN2_SNS_CP0_PARAM_ID                      (0x6E000092u)

#define CapSense_SNR_TEST_WIDGET_ID_VALUE                   (CapSense_dsRam.snrTestWidgetId)
#define CapSense_SNR_TEST_WIDGET_ID_OFFSET                  (147u)
#define CapSense_SNR_TEST_WIDGET_ID_SIZE                    (1u)
#define CapSense_SNR_TEST_WIDGET_ID_PARAM_ID                (0x68000093u)

#define CapSense_SNR_TEST_SENSOR_ID_VALUE                   (CapSense_dsRam.snrTestSensorId)
#define CapSense_SNR_TEST_SENSOR_ID_OFFSET                  (148u)
#define CapSense_SNR_TEST_SENSOR_ID_SIZE                    (1u)
#define CapSense_SNR_TEST_SENSOR_ID_PARAM_ID                (0x63000094u)

#define CapSense_SNR_TEST_SCAN_COUNTER_VALUE                (CapSense_dsRam.snrTestScanCounter)
#define CapSense_SNR_TEST_SCAN_COUNTER_OFFSET               (150u)
#define CapSense_SNR_TEST_SCAN_COUNTER_SIZE                 (2u)
#define CapSense_SNR_TEST_SCAN_COUNTER_PARAM_ID             (0x8C000096u)

#define CapSense_SNR_TEST_RAW_COUNT0_VALUE                  (CapSense_dsRam.snrTestRawCount[0u])
#define CapSense_SNR_TEST_RAW_COUNT0_OFFSET                 (152u)
#define CapSense_SNR_TEST_RAW_COUNT0_SIZE                   (2u)
#define CapSense_SNR_TEST_RAW_COUNT0_PARAM_ID               (0x83000098u)


/*****************************************************************************/
/* Flash Data structure register definitions                                 */
/*****************************************************************************/
#define CapSense_BTN0_PTR2SNS_FLASH_VALUE                   (CapSense_dsFlash.wdgtArray[0].ptr2SnsFlash)
#define CapSense_BTN0_PTR2SNS_FLASH_OFFSET                  (0u)
#define CapSense_BTN0_PTR2SNS_FLASH_SIZE                    (4u)
#define CapSense_BTN0_PTR2SNS_FLASH_PARAM_ID                (0xD1000000u)

#define CapSense_BTN0_PTR2WD_RAM_VALUE                      (CapSense_dsFlash.wdgtArray[0].ptr2WdgtRam)
#define CapSense_BTN0_PTR2WD_RAM_OFFSET                     (4u)
#define CapSense_BTN0_PTR2WD_RAM_SIZE                       (4u)
#define CapSense_BTN0_PTR2WD_RAM_PARAM_ID                   (0xD0000004u)

#define CapSense_BTN0_PTR2SNS_RAM_VALUE                     (CapSense_dsFlash.wdgtArray[0].ptr2SnsRam)
#define CapSense_BTN0_PTR2SNS_RAM_OFFSET                    (8u)
#define CapSense_BTN0_PTR2SNS_RAM_SIZE                      (4u)
#define CapSense_BTN0_PTR2SNS_RAM_PARAM_ID                  (0xD3000008u)

#define CapSense_BTN0_PTR2FLTR_HISTORY_VALUE                (CapSense_dsFlash.wdgtArray[0].ptr2FltrHistory)
#define CapSense_BTN0_PTR2FLTR_HISTORY_OFFSET               (12u)
#define CapSense_BTN0_PTR2FLTR_HISTORY_SIZE                 (4u)
#define CapSense_BTN0_PTR2FLTR_HISTORY_PARAM_ID             (0xD200000Cu)

#define CapSense_BTN0_PTR2DEBOUNCE_VALUE                    (CapSense_dsFlash.wdgtArray[0].ptr2DebounceArr)
#define CapSense_BTN0_PTR2DEBOUNCE_OFFSET                   (16u)
#define CapSense_BTN0_PTR2DEBOUNCE_SIZE                     (4u)
#define CapSense_BTN0_PTR2DEBOUNCE_PARAM_ID                 (0xD4000010u)

#define CapSense_BTN0_STATIC_CONFIG_VALUE                   (CapSense_dsFlash.wdgtArray[0].staticConfig)
#define CapSense_BTN0_STATIC_CONFIG_OFFSET                  (20u)
#define CapSense_BTN0_STATIC_CONFIG_SIZE                    (4u)
#define CapSense_BTN0_STATIC_CONFIG_PARAM_ID                (0xD5000014u)

#define CapSense_BTN0_TOTAL_NUM_SNS_VALUE                   (CapSense_dsFlash.wdgtArray[0].totalNumSns)
#define CapSense_BTN0_TOTAL_NUM_SNS_OFFSET                  (24u)
#define CapSense_BTN0_TOTAL_NUM_SNS_SIZE                    (2u)
#define CapSense_BTN0_TOTAL_NUM_SNS_PARAM_ID                (0x99000018u)

#define CapSense_BTN0_TYPE_VALUE                            (CapSense_dsFlash.wdgtArray[0].wdgtType)
#define CapSense_BTN0_TYPE_OFFSET                           (26u)
#define CapSense_BTN0_TYPE_SIZE                             (1u)
#define CapSense_BTN0_TYPE_PARAM_ID                         (0x5D00001Au)

#define CapSense_BTN0_NUM_COLS_VALUE                        (CapSense_dsFlash.wdgtArray[0].numCols)
#define CapSense_BTN0_NUM_COLS_OFFSET                       (27u)
#define CapSense_BTN0_NUM_COLS_SIZE                         (1u)
#define CapSense_BTN0_NUM_COLS_PARAM_ID                     (0x5B00001Bu)

#define CapSense_BTN0_PTR2SNS_CP_VALUE                      (CapSense_dsFlash.wdgtArray[0].ptr2SnsCpArr)
#define CapSense_BTN0_PTR2SNS_CP_OFFSET                     (28u)
#define CapSense_BTN0_PTR2SNS_CP_SIZE                       (4u)
#define CapSense_BTN0_PTR2SNS_CP_PARAM_ID                   (0xD700001Cu)

#define CapSense_BTN1_PTR2SNS_FLASH_VALUE                   (CapSense_dsFlash.wdgtArray[1].ptr2SnsFlash)
#define CapSense_BTN1_PTR2SNS_FLASH_OFFSET                  (32u)
#define CapSense_BTN1_PTR2SNS_FLASH_SIZE                    (4u)
#define CapSense_BTN1_PTR2SNS_FLASH_PARAM_ID                (0xD8010020u)

#define CapSense_BTN1_PTR2WD_RAM_VALUE                      (CapSense_dsFlash.wdgtArray[1].ptr2WdgtRam)
#define CapSense_BTN1_PTR2WD_RAM_OFFSET                     (36u)
#define CapSense_BTN1_PTR2WD_RAM_SIZE                       (4u)
#define CapSense_BTN1_PTR2WD_RAM_PARAM_ID                   (0xD9010024u)

#define CapSense_BTN1_PTR2SNS_RAM_VALUE                     (CapSense_dsFlash.wdgtArray[1].ptr2SnsRam)
#define CapSense_BTN1_PTR2SNS_RAM_OFFSET                    (40u)
#define CapSense_BTN1_PTR2SNS_RAM_SIZE                      (4u)
#define CapSense_BTN1_PTR2SNS_RAM_PARAM_ID                  (0xDA010028u)

#define CapSense_BTN1_PTR2FLTR_HISTORY_VALUE                (CapSense_dsFlash.wdgtArray[1].ptr2FltrHistory)
#define CapSense_BTN1_PTR2FLTR_HISTORY_OFFSET               (44u)
#define CapSense_BTN1_PTR2FLTR_HISTORY_SIZE                 (4u)
#define CapSense_BTN1_PTR2FLTR_HISTORY_PARAM_ID             (0xDB01002Cu)

#define CapSense_BTN1_PTR2DEBOUNCE_VALUE                    (CapSense_dsFlash.wdgtArray[1].ptr2DebounceArr)
#define CapSense_BTN1_PTR2DEBOUNCE_OFFSET                   (48u)
#define CapSense_BTN1_PTR2DEBOUNCE_SIZE                     (4u)
#define CapSense_BTN1_PTR2DEBOUNCE_PARAM_ID                 (0xDD010030u)

#define CapSense_BTN1_STATIC_CONFIG_VALUE                   (CapSense_dsFlash.wdgtArray[1].staticConfig)
#define CapSense_BTN1_STATIC_CONFIG_OFFSET                  (52u)
#define CapSense_BTN1_STATIC_CONFIG_SIZE                    (4u)
#define CapSense_BTN1_STATIC_CONFIG_PARAM_ID                (0xDC010034u)

#define CapSense_BTN1_TOTAL_NUM_SNS_VALUE                   (CapSense_dsFlash.wdgtArray[1].totalNumSns)
#define CapSense_BTN1_TOTAL_NUM_SNS_OFFSET                  (56u)
#define CapSense_BTN1_TOTAL_NUM_SNS_SIZE                    (2u)
#define CapSense_BTN1_TOTAL_NUM_SNS_PARAM_ID                (0x90010038u)

#define CapSense_BTN1_TYPE_VALUE                            (CapSense_dsFlash.wdgtArray[1].wdgtType)
#define CapSense_BTN1_TYPE_OFFSET                           (58u)
#define CapSense_BTN1_TYPE_SIZE                             (1u)
#define CapSense_BTN1_TYPE_PARAM_ID                         (0x5401003Au)

#define CapSense_BTN1_NUM_COLS_VALUE                        (CapSense_dsFlash.wdgtArray[1].numCols)
#define CapSense_BTN1_NUM_COLS_OFFSET                       (59u)
#define CapSense_BTN1_NUM_COLS_SIZE                         (1u)
#define CapSense_BTN1_NUM_COLS_PARAM_ID                     (0x5201003Bu)

#define CapSense_BTN1_PTR2SNS_CP_VALUE                      (CapSense_dsFlash.wdgtArray[1].ptr2SnsCpArr)
#define CapSense_BTN1_PTR2SNS_CP_OFFSET                     (60u)
#define CapSense_BTN1_PTR2SNS_CP_SIZE                       (4u)
#define CapSense_BTN1_PTR2SNS_CP_PARAM_ID                   (0xDE01003Cu)

#define CapSense_BTN2_PTR2SNS_FLASH_VALUE                   (CapSense_dsFlash.wdgtArray[2].ptr2SnsFlash)
#define CapSense_BTN2_PTR2SNS_FLASH_OFFSET                  (64u)
#define CapSense_BTN2_PTR2SNS_FLASH_SIZE                    (4u)
#define CapSense_BTN2_PTR2SNS_FLASH_PARAM_ID                (0xDA020040u)

#define CapSense_BTN2_PTR2WD_RAM_VALUE                      (CapSense_dsFlash.wdgtArray[2].ptr2WdgtRam)
#define CapSense_BTN2_PTR2WD_RAM_OFFSET                     (68u)
#define CapSense_BTN2_PTR2WD_RAM_SIZE                       (4u)
#define CapSense_BTN2_PTR2WD_RAM_PARAM_ID                   (0xDB020044u)

#define CapSense_BTN2_PTR2SNS_RAM_VALUE                     (CapSense_dsFlash.wdgtArray[2].ptr2SnsRam)
#define CapSense_BTN2_PTR2SNS_RAM_OFFSET                    (72u)
#define CapSense_BTN2_PTR2SNS_RAM_SIZE                      (4u)
#define CapSense_BTN2_PTR2SNS_RAM_PARAM_ID                  (0xD8020048u)

#define CapSense_BTN2_PTR2FLTR_HISTORY_VALUE                (CapSense_dsFlash.wdgtArray[2].ptr2FltrHistory)
#define CapSense_BTN2_PTR2FLTR_HISTORY_OFFSET               (76u)
#define CapSense_BTN2_PTR2FLTR_HISTORY_SIZE                 (4u)
#define CapSense_BTN2_PTR2FLTR_HISTORY_PARAM_ID             (0xD902004Cu)

#define CapSense_BTN2_PTR2DEBOUNCE_VALUE                    (CapSense_dsFlash.wdgtArray[2].ptr2DebounceArr)
#define CapSense_BTN2_PTR2DEBOUNCE_OFFSET                   (80u)
#define CapSense_BTN2_PTR2DEBOUNCE_SIZE                     (4u)
#define CapSense_BTN2_PTR2DEBOUNCE_PARAM_ID                 (0xDF020050u)

#define CapSense_BTN2_STATIC_CONFIG_VALUE                   (CapSense_dsFlash.wdgtArray[2].staticConfig)
#define CapSense_BTN2_STATIC_CONFIG_OFFSET                  (84u)
#define CapSense_BTN2_STATIC_CONFIG_SIZE                    (4u)
#define CapSense_BTN2_STATIC_CONFIG_PARAM_ID                (0xDE020054u)

#define CapSense_BTN2_TOTAL_NUM_SNS_VALUE                   (CapSense_dsFlash.wdgtArray[2].totalNumSns)
#define CapSense_BTN2_TOTAL_NUM_SNS_OFFSET                  (88u)
#define CapSense_BTN2_TOTAL_NUM_SNS_SIZE                    (2u)
#define CapSense_BTN2_TOTAL_NUM_SNS_PARAM_ID                (0x92020058u)

#define CapSense_BTN2_TYPE_VALUE                            (CapSense_dsFlash.wdgtArray[2].wdgtType)
#define CapSense_BTN2_TYPE_OFFSET                           (90u)
#define CapSense_BTN2_TYPE_SIZE                             (1u)
#define CapSense_BTN2_TYPE_PARAM_ID                         (0x5602005Au)

#define CapSense_BTN2_NUM_COLS_VALUE                        (CapSense_dsFlash.wdgtArray[2].numCols)
#define CapSense_BTN2_NUM_COLS_OFFSET                       (91u)
#define CapSense_BTN2_NUM_COLS_SIZE                         (1u)
#define CapSense_BTN2_NUM_COLS_PARAM_ID                     (0x5002005Bu)

#define CapSense_BTN2_PTR2SNS_CP_VALUE                      (CapSense_dsFlash.wdgtArray[2].ptr2SnsCpArr)
#define CapSense_BTN2_PTR2SNS_CP_OFFSET                     (92u)
#define CapSense_BTN2_PTR2SNS_CP_SIZE                       (4u)
#define CapSense_BTN2_PTR2SNS_CP_PARAM_ID                   (0xDC02005Cu)


#endif /* End CY_SENSE_CapSense_REGISTER_MAP_H */


/* [] END OF FILE */
